@@ -39,7 +39,10 @@ class Accountant:
         blocked_balance_withdraw_book = self.ledger.get_book_balances(book_id=self.bank_account['ledger_books']['blocked_balance']['id'], metadata_filter={'operation': 'WITHDRAW'}, timestamp=timestamp)
         blocked_balance_order_book = self.ledger.get_book_balances(book_id=self.bank_account['ledger_books']['blocked_balance']['id'], metadata_filter={'operation': 'ORDER'}, timestamp=timestamp)
         book_balance = []
-        for currency, amount in blocked_balance_book.items():
+        block_book_currency_list = [currency for currency, amount in blocked_balance_book.items()]
+        main_book_currency_list =  [currency for currency, amount in main_balance_book.items()]
+        all_currency_list = list(set(block_book_currency_list + main_book_currency_list))
+        for currency in all_currency_list:
             if currency in main_balance_book:
                 main_balance = main_balance_book[currency]
             else:
